@@ -10,7 +10,7 @@ from tuxsuite.download import download_file
 @pytest.fixture
 def build(mocker):
     b = mocker.MagicMock()
-    b.build_key = "4c6f477bf568ea2ad409fd68a404492f"
+    b.uid = "4c6f477bf568ea2ad409fd68a404492f"
     b.build_data = "https://builds.test/4c6f477bf568ea2ad409fd68a404492f/"
     return b
 
