@@ -361,6 +361,20 @@ def test_submit(config, plan_config, mocker):
     assert len(plan.builds) == 11
     assert len(plan.tests) == 30
 
+    # batch process test
+    """
+    after post request, the returned list of object is used to update plan.status["builds"]
+    with tuxapi returned object along with uid and downlaod url
+    """
+    assert len(plan.status["builds"]) == 11
+    # checking updated status of builds after batch processing
+    builds = plan.status["builds"]
+    index = 0
+    for uid, status in builds.items():
+        assert uid == f"my-build-{index:02}"
+        assert status["download_url"] == f"http://url/{uid}"
+        index += 1
+
 
 def test_bake_submit(config, bake_plan_config, mocker):
     cfg = PlanConfig("", "", bake_plan_config)
@@ -411,6 +425,20 @@ def test_bake_submit(config, bake_plan_config, mocker):
     assert len(plan.builds) == 3
     assert len(plan.tests) == 0
 
+    # batch process test
+    """
+    after post request, the returned list of object is used to update plan.status["builds"]
+    with tuxapi returned object along with uid and downlaod url
+    """
+    assert len(plan.status["builds"]) == 3
+    # checking updated status of builds after batch processing
+    builds = plan.status["builds"]
+    index = 0
+    for uid, status in builds.items():
+        assert uid == f"my-build-{index:02}"
+        assert status["download_url"] == f"http://url/{uid}"
+        index += 1
+
 
 def test_bake_plan_extended_config_submit(config, bake_plan_extended_config, mocker):
     cfg = PlanConfig("", "", bake_plan_extended_config)
