@@ -5,7 +5,7 @@
 This is the tuxsuite module.
 """
 
-__version__ = "1.7.4"
+__version__ = "1.8.0"
 
 
 from . import build
@@ -196,7 +196,17 @@ class BuildPlan(PlanType):
                 build_entry, patch = b.generate_build_request(plan=plan.plan)
                 req_data["builds"].append(build_entry)
                 req_data["patches"].update(patch)
-            ret = build.post_request(f"{plan.url}/builds", plan.headers, req_data)
+
+            # submit in batches of 500 to prevent tuxapi lambda time out
+            ret = []
+            for i in range(0, len(req_data["builds"]), 500):
+                batch_data = {
+                    "builds": req_data["builds"][i : i + 500],
+                    "patches": req_data["patches"],
+                }
+                ret += build.post_request(
+                    f"{plan.url}/builds", plan.headers, batch_data
+                )
             # Updating builds_to_submit will update values in builds
             for build_obj, data in zip(builds_to_submit, ret):
                 build_obj.build_data = f"{plan.url}/builds/{data['uid']}"
@@ -230,7 +240,7 @@ class BakePlan(PlanType):
         print("Running Bake plan '{}': '{}'".format(name, description))
 
     def create_builds(self, plan, builds):
-        req_data = {"oebuilds": []}
+        req_data = {"oebuilds": [], "manifests": {}}
         # handling options
         no_cache = plan.args.get("no_cache", False)
         local_manifest = plan.args.get("manifest_file")
@@ -277,7 +287,16 @@ class BakePlan(PlanType):
                 build_entry, _ = b.generate_build_request(plan=plan.plan)
                 req_data["oebuilds"].append(build_entry)
 
-            ret = build.post_request(f"{plan.url}/oebuilds", plan.headers, req_data)
+            # submit in batches of 500 to prevent tuxapi lambda time out
+            ret = []
+            for i in range(0, len(req_data["oebuilds"]), 500):
+                batch_data = {
+                    "oebuilds": req_data["oebuilds"][i : i + 500],
+                    "manifests": req_data["manifests"],
+                }
+                ret += build.post_request(
+                    f"{plan.url}/oebuilds", plan.headers, batch_data
+                )
             # Updating builds_to_submit will update values in builds
             for bake_obj, data in zip(builds_to_submit, ret):
                 bake_obj.build_data = f"{plan.url}/oebuilds/{data['uid']}"
