@@ -607,11 +607,17 @@ class Plan(HeadersMixin):
                     )
 
         if tests:
-            ret = post_request(
-                f"{self.url}/tests",
-                self.headers,
-                [t.generate_test_request(plan=self.plan) for t in tests],
-            )
+            ret = []
+            # submit in batches of 500 to prevent tuxapi lambda time out
+            for i in range(0, len(tests), 500):
+                ret += post_request(
+                    f"{self.url}/tests",
+                    self.headers,
+                    [
+                        t.generate_test_request(plan=self.plan)
+                        for t in tests[i : i + 500]
+                    ],
+                )
             for test, data in zip(tests, ret):
                 test.uid = data["uid"]
                 test.status = data
