@@ -296,21 +296,22 @@ def handle_submit(cmdargs, _, config):
 
     try:
         test = tuxsuite.Test(
-            device=cmdargs.device,
-            kernel=cmdargs.kernel,
             ap_romfw=cmdargs.ap_romfw,
+            bios=cmdargs.bios,
+            boot_args=cmdargs.boot_args,
+            device=cmdargs.device,
             dtb=cmdargs.dtb,
+            fip=cmdargs.fip,
+            kernel=cmdargs.kernel,
             mcp_fw=cmdargs.mcp_fw,
             mcp_romfw=cmdargs.mcp_romfw,
             modules=cmdargs.modules,
+            parameters=params,
             rootfs=cmdargs.rootfs,
             scp_fw=cmdargs.scp_fw,
             scp_romfw=cmdargs.scp_romfw,
-            fip=cmdargs.fip,
-            parameters=params,
             tests=tests,
             timeouts=timeouts_d,
-            boot_args=cmdargs.boot_args,
             wait_for=cmdargs.wait_for,
         )
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
@@ -364,6 +365,12 @@ def test_cmd_options(sp):
         default=None,
         type=str,
     )
+    sp.add_argument(
+        "--bios",
+        help="URL of the bios to test",
+        default=None,
+        type=str,
+    )
     sp.add_argument(
         "--dtb",
         help="URL of the dtb to test",
